@@ -102,6 +102,9 @@ Explode.explodeSelection = function(di, toolTitle) {
         // these entity types are not explodable:
         if (isPointEntity(entity) ||
             isLineEntity(entity) ||
+            isXLineEntity(entity) ||
+            isRayEntity(entity) ||
+            isImageEntity(entity) ||
             isArcEntity(entity) ||
             isViewportEntity(entity)) {
             continue;
@@ -325,6 +328,8 @@ Explode.explodeEntity = function(entity, options) {
         e = new RTextEntity(entity.getDocument(), textData);
         e.setSelected(true);
         e.copyAttributesFrom(entity.data());
+        var textColor = document.getKnownVariable(RS.DIMCLRT, new RColor(RColor.ByBlock));
+        e.setColor(textColor);
         ret.push(e);
     }
 
@@ -337,6 +342,27 @@ Explode.explodeEntity = function(entity, options) {
         }
     }
 
+    // explode tolerances into lines and texts:
+    else if (isToleranceEntity(entity)) {
+        shapes = entity.getFrame();
+        for (k=0; k<shapes.length; k++) {
+            shape = shapes[k];
+            ret.push(shape.clone());
+        }
+
+        var textDatas = entity.getTextLabels();
+        for (k=0; k<textDatas.length; k++) {
+            var d = textDatas[k];
+            e = new RTextEntity(document, new RTextData(d))
+            e.setSelected(true);
+            e.copyAttributesFrom(entity.data());
+            if (e.getColor()!==d.getColor()) {
+                e.setColor(d.getColor());
+            }
+            ret.push(e);
+        }
+    }
+
     // explode solids into polylines:
     else if (isSolidEntity(entity)) {
         shapes = entity.getShapes();
@@ -480,7 +506,7 @@ Explode.explodeEntity = function(entity, options) {
         if (data.getColumnCount()>1 || data.getRowCount()>1) {
             for (col=0; col<data.getColumnCount(); col++) {
                 for (row=0; row<data.getRowCount(); row++) {
-                    var offset = data.getColumnRowOffset(col, row);
+                    var offset = data.getColumnRowOffset(col, row, true);
 
                     e = entity.clone();
                     e.setRowCount(1);
@@ -497,7 +523,7 @@ Explode.explodeEntity = function(entity, options) {
         else {
             var subIds = document.queryBlockEntities(data.getReferencedBlockId());
             for (k=0; k<subIds.length; k++) {
-                var subEntity = data.queryEntity(subIds[k]);
+                var subEntity = data.queryEntity(subIds[k], true);
                 if (isNull(subEntity)) {
                     continue;
                 }
